# -*- coding: utf-8 -*-

"""Main Controller"""
from tg import expose, flash, require, url, request, redirect, app_globals, tmpl_context, validate
from tg import tmpl_context
from pylons.i18n import ugettext as _, lazy_ugettext as l_
from catwalk.tg2 import Catwalk
from repoze.what import predicates

from luci.controllers.decorators import *
from luci.lib.base import BaseController

from luci.controllers.error import ErrorController
from luci.controllers.secure import SecureController

from luci.model import DBSession, metadata
from luci import model
#from luci.widgets.fdom_add_form import create_fdom_add_form

from luci.widgets.add_system_form import create_add_system_form
from luci.widgets.add_existing_form import create_add_existing_form
from luci.widgets.add_user_form import create_add_user_form
from luci.widgets.manage_systems_form import create_manage_systems_form
from luci.widgets.create_cluster_form import create_cluster_form

__all__ = ['RootController']


# Imports into module's namespace.
scheme = app_globals.scheme


@mountSubControllers(scheme.mounts())
class RootController(BaseController):
    """
    The root controller for the luci application.

    All the other controllers and WSGI applications should be mounted on this
    controller. For example::

        panel = ControlPanelController()
        another_app = AnotherWSGIApplication()

    Keep in mind that WSGI applications shouldn't be mounted directly: They
    must be wrapped around with :class:`tg.controllers.WSGIAppController`.

    """

    def __call__(self, environ, start_response):
        """Invoke the Controller"""
        tmpl_context.title_list = []
        tmpl_context.already_used = dict()
        tmpl_context.already_used.setdefault(False)
        return BaseController.__call__(self, environ, start_response)

    # SUBCONTROLLERS

    secc = SecureController()
    admin = Catwalk(model, DBSession)
    error = ErrorController()

    # METHODS OF THE ROOT CONTROLLER
    
    @expose('luci.templates.index')
    def index(self):
        """Handle the front-page."""
        return dict(page='index')

    @expose('luci.templates.about')
    def about(self):
        """Handle the 'about' page."""
        return dict(page='about')

    @expose('luci.templates.homebase')
    def homebase(self, homebasepage='homebasepage', **args):
        if homebasepage == 'addsystem':
            tmpl_context.form = create_add_system_form
        elif homebasepage == 'addexisting':
            tmpl_context.form = create_add_existing_form
            if request.method == 'POST':
                flash('psted')
        elif homebasepage == 'adduser':
            tmpl_context.form = create_add_user_form
        elif homebasepage == 'managesystems':
            tmpl_context.form = create_manage_systems_form

        return dict(page='homebase',homebasepage=homebasepage,args=args)

    @expose('luci.templates.cluster')
    def cluster(self, clusterpage='clusterlist', **args):
        if clusterpage == 'createcluster':
            tmpl_context.form = create_cluster_form
            if request.method == 'POST':
                #flash('current is %s %s [%s]' % (clusterpage, request.method, str(args)), 'error')
                from luci.widget_validators.validate_create_cluster_form import validate_create_cluster_form
                validate_create_cluster_form(self, **args)
        return dict(page='cluster', clusterpage=clusterpage)

    @expose('luci.templates.storage')
    def storage(self,storagepage='systemlist'):
        return dict(page='storage', storagepage=storagepage)

    # TODO: Automatically generated/experimental methods? Perhaps clean needed.

    @expose('luci.templates.authentication')
    def auth(self):
        """Display some information about auth* on this application."""
        return dict(page='auth')

    @expose('luci.templates.index')
    @require(predicates.has_permission('manage', msg=l_('Only for managers')))
    def manage_permission_only(self, **kw):
        """Illustrate how a page for managers only works."""
        return dict(page='managers stuff')

    @expose('luci.templates.index')
    @require(predicates.is_user('editor', msg=l_('Only for the editor')))
    def editor_user_only(self, **kw):
        """Illustrate how a page exclusive for the editor works."""
        return dict(page='editor stuff')

    @expose('luci.templates.login')
    def login(self, came_from=url('/')):
        """Start the user login."""
        login_counter = request.environ['repoze.who.logins']
        if login_counter > 0:
            flash(_('Wrong credentials'), 'warning')
        return dict(page='login', login_counter=str(login_counter),
                    came_from=came_from)

    @expose()
    def post_login(self, came_from=url('/')):
        """
        Redirect the user to the initially requested page on successful
        authentication or redirect her back to the login page if login failed.

        """
        if not request.identity:
            login_counter = request.environ['repoze.who.logins'] + 1
            redirect(url('/login', came_from=came_from, __logins=login_counter))
        userid = request.identity['repoze.who.userid']
        flash(_('Welcome back, %s!') % userid)
        redirect(came_from)

    @expose()
    def post_logout(self, came_from=url('/')):
        """
        Redirect the user to the initially requested page on logout and say
        goodbye as well.

        """
        flash(_('We hope to see you soon!'))
        redirect(came_from)
