# -*- coding: utf-8 -*-

"""Constants and functions regarding the (logical) scheme of the Luci."""

__all__ = ['LuciScheme']


class LuciScheme:

    # Static URL prefix (excluding host part and slash both at the beginning and
    # at the end). E.g. 'luci' for Luci application starting at
    # <http://example.com/luci/>.
    APP_PREFIX = u''


    # First level of the scheme.
    CLUSTERS = u'clusters'
    USERS = u'users'
    STORAGE = u'storage'
    SYSTEMS = u'systems'

    @classmethod
    def mounts(cls):
        """Defined as a method to avoid circular."""
        # TODO: getter?
        from luci.controllers.cluster import ClusterController, \
                                             ClusterCmdController
#        from luci.controllers.storage import StorageController, \
#                                             StorageCmdController

        return {
            cls.CLUSTERS: (ClusterController, ClusterCmdController)
#            cls.USERS:    (UsersController, UsersCmdController],
#            cls.STORAGE:  (StorageController, StorageCmdController),
#            cls.SYSTEMS:  (SystemsController, SystemsCmdController)
        }


    # Second level of the scheme -- `Clusters'.

    class ClusterScheme:
        NODES = u'nodes'
        SERVICES = u'services'
        FAILOVERS = u'failovers'
        FENCES = u'fences'

        @classmethod
        def mounts(cls):
            from luci.controllers.cluster_part import *
            return {
                cls.NODES:     (NodeController, NodeCmdController),
                cls.SERVICES:  (ServiceController, ServiceCmdController),
                cls.FAILOVERS: (FailoverController, FailoverCmdController),
                cls.FENCES:    (FenceController, FenceCmdController)
            }


    """Suffix which makes identifier of base subcontroller unique.

    Such unique identifier can be then used as an identifier of `commands
    subcontroller'.

    """
    CTRL_CMD_SUFFIX = u'_cmd'

    @classmethod
    def base2CmdCtrl(cls, base):
        """Convert `base controller' -- `command subcontroller' name."""
        return base + cls.CTRL_CMD_SUFFIX

    @classmethod
    def cmd2BaseCtrl(cls, cmd):
        """Convert `command subcontroller' -- `base controller' name."""
        return cmd[:cmd.rfind(cls.CTRL_CMD_SUFFIX)]

