# -*- coding: utf-8 -*-

"""The base Controller API."""

from tg import TGController, tmpl_context, flash, app_globals
#from tg.render import render
from tg import request
#from pylons.i18n import _, ungettext, N_
#from tw.api import WidgetBunch

import luci.model as model
from luci.controllers.decorators import forImmediateRedirect
from luci.lib.helpers import urlList2String
from luci.lib.strings import VerboseStrings

__all__ = ['BaseController', 'Subcontroller', 'SubcontrollerApplyMixin']


# Imports into module's namespace.
form_utils = app_globals.form_utils


class BaseController(TGController):
    """
    Base class for the controllers in the application.

    Your web application should have one of these. The root of
    your application is used to compute URLs used by your app.

    """

    def __call__(self, environ, start_response):
        """Invoke the Controller"""
        # TGController.__call__ dispatches to the Controller method
        # the request is routed to. This routing information is
        # available in environ['pylons.routes_dict']

        request.identity = request.environ.get('repoze.who.identity')
        tmpl_context.identity = request.identity
        return TGController.__call__(self, environ, start_response)


class Subcontroller(object):
    """Base class for subcontrollers.

    Keyword arguments passed on object creation are automatically moved
    inside the object as its attributes.

    """

    def __new__(cls, *args, **kwargs):
        # If the class that invoked this method is directly inherited from this
        # class, set new attributes according to passed keyword arguments
        # and delegate this invocation upwards (omitting the level
        # of Subcontroller class).
        # Otherwise, delegate the invocation directly upwards.
        if cls.__base__.__name__ == 'Subcontroller':
            for kw, v in kwargs.iteritems():
                setattr(cls, kw, v)
            return BaseController.__new__(cls, *args)
        else:
            return cls.__base__.__new__(cls, *args, **kwargs)


class SubcontrollerApplyMixin:
    """Mixin that adds 'apply' method to the derived controller."""

    @forImmediateRedirect(allowed_methods = ('GET', 'POST'))
    def apply(self, name=None, **kwargs):
        """Handle applying a command over selected node(s).

        Class using this mixin has to define attribute '_apply_cmds' that
        contains object that defines attribute 'cmds', which is a dictionary.
        
        Example of definition of such object:
        ---
        class ApplyCommands:
            DELETE = 'cmd_delete'

            def _delete(which):
                ...
                return msg, status, False

            # Mapping.
            cmds = {DELETE: _delete}
        
            _delete = staticmethod(_delete)
        ---
        
        This method takes all keyword arguments (taken from URL) and try
        to find a command identifier first (e.g. 'cmd_delete' from example
        above, but there can be more of them).
        Then it prepares a list of identifiers (sort of entity depends
        on the context of use, e.g. nodes) in this manner:
            1) if name argument was specified, than the list consists of one
               item -- this name
            2) otherwise the list consists of identifiers (taken from the rest
               of keyword arguments) converted back to string form (they are
               supposed to be previously converted to HTML form-safe sequences)
        Then it calls associated function ('_delete' from example above),
        passing the mentioned list of identifiers.
        
        Such called function ('_delete' from example above) should return
        2- or 3-tuple (msg, status [, use_referrer]), where:
            msg           Message to be displayed (e.g. 'entity X deleted').
            status        Status argument for tg.flash ('info', 'warning', ...).
            use_referrer  Whether to allow use referrer (if available)
                          for redirection target.
        
        Keyword arguments:
            name    Name of the entity to be used (if GET method is used).
            kwargs  Dict of entities to be used (if POST method is used).

        """
        cmd_set = False
        cmds_used = set(kwargs).intersection(self._apply_cmds.cmds)
        if len(cmds_used) == 1:
            cmd_set = True
            cmd = cmds_used.pop()
            kwargs.pop(cmd)

        use_referrer = True
        if not cmd_set:
            # If Luci's templates are consistent, this should never happen.
            msg = VerboseStrings.INTERNAL_ERROR
            status = 'error'
        else:
            if name:
                which = [name]
            else:
                which = [form_utils.id2String(s) for s in kwargs.iterkeys()]

            if not which:
                msg = VerboseStrings.NOTHING_CHOSEN
                status ='warning'
            else:
                retval = self._apply_cmds.cmds[cmd](which)
                unpacker = lambda msg, status, use_referrer=True: \
                           (msg, status, use_referrer)
                msg, status, use_referrer = unpacker(*retval)

        flash(msg, status=status)
        base_url_str = urlList2String(tmpl_context.cluster_url, self.base_name)
        return dict(use_referrer=use_referrer, redir_target=base_url_str)
