# -*- coding: utf-8 -*-
"""Static demo data."""

__all__ = ['ClusterData']


class ClusterData:
    """Class representation of overall demo data."""
    def __init__(self):
        self.clusters = {'ClusterOne': ClusterOne(),
                         'ClusterTwo': ClusterTwo(),
                         'ClusterThree': ClusterThree()}
        self.storage = {'storage_a': StorageA(),
                        'storage_b': StorageB(),
                        'storage_c': StorageC()}


# Certain clusters.

class Cluster:
    """Base class for certain cluster."""

    NODE_ACTIVE = '0'
    NODE_UNKNOWN = '1'
    NODE_INACTIVE = '2'

    CLUSTER_OK = '0'
    CLUSTER_UNKNOWN = '1'
    CLUSTER_NOT_OK = '2'


class ClusterOne(Cluster):
    """Data for 'ClusterOne'."""
    def __init__(self):
        self.status = self.CLUSTER_OK
        self.cluster_votes = 2
        self.required_quorum = 1

        self.nodes = \
            {'NodeAlpha':   {'ip':          '144.92.235.11',
                             'serviceload': 10,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service W'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeBeta':    {'ip':          '144.92.235.12',
                             'serviceload': 20,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service X', 'Service Y', 'Service Z'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeDelta':   {'ip':          '144.92.235.13',
                             'serviceload': 30,
                             'status':      self.NODE_INACTIVE,
                             'msg': 'Something terrible',
                             'services':    ('Service X'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeGamma':   {'ip':          '144.92.235.14',
                             'serviceload': 40,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service Y'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeEpsilon': {'ip':          '144.92.235.15',
                             'serviceload': 50,
                             'status':      self.NODE_UNKNOWN,
                             'services':    ('Service Z'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}}}

        self.services = \
            {'Service W':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover1',
                            'node':      'NodeGamma',
                            'resources': {'Res A': ('Script', False)}},
            'Service Y':   {'running':   False,
                            'autostart': False,
                            #'failover':   None,
                            'node':      'NodeAlpha',
                            'resources': {'Res A': ('Script', False)}},
            'Service X':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover2',
                            'node':      'NodeBeta',
                            'resources': {'Resource1': ('Script',False),
                                          'Resource2': ('Apache',True),
                                          'Resource3': ('LVM',False),
                                          'Resource4': ('IP Address',True),
                                          'Resource5': ('GFS File System',False)}},
            'Service Z':   {'running':   False,
                            'autostart': True,
                            #'failover':   None,
                            'node':      'NodeDelta',
                            'resources': {'Res A': ('Script', False)}}}

        self.failovers = \
            {'Failover1':{'prioritized': False,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service Y',
                                          'Service X'),
                          'nodes':       {'NodeAlpha': 1,
                                          'NodeBeta': 2}},
             'Failover2':{'prioritized': True,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service X',
                                          'Service Y',
                                          'Service Z'),
                          'nodes':       {'NodeAlpha': 1,
                                          'NodeBeta': 2,
                                          'NodeEpsilon': 0}},
             'FDOM a':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service W',
                                          'Service Z'),
                          'nodes':       {'NodeBeta': 1,
                                          'NodeGamma': 0}},
             'FDOM b':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service Y'),
                          'nodes':       {'NodeDelta': 0,
                                          'NodeGamma': 0}},
             'FDOM c':   {'prioritized': True,
                          'restricted':  True,
                          'failback':    True,
                          'services':    ('Service Z',
                                          'Service X',
                                          'Service W'),
                          'nodes':       {'NodeAlpha': 1,
                                          'NodeEpsilon': 0}}}

        self.fences = \
            {'Fence A':{'type': 'iLO',
                        'host': 'hostname.host.org',
                        'ip':   '123.123.78.90',
                        'port': 6666,
                        'nodes': {'NodeDelta': 1}},
             'Fence B':{'type': 'APC Power Device',
                        'host': 'fenceb.host.org',
                        'ip':   '123.123.78.11',
                        'port': 6667,
                        'nodes': {'NodeAlpha': 1,
                                  'NodeDelta': 2}},
             'Fence C':{'type': 'Virtual Machine',
                        'host': 'fencec.host.org',
                        'ip':   '123.123.78.156',
                        'port': 11023,
                        'nodes': {'NodeAlpha': 1,
                                  'NodeBeta': 2,
                                  'NodeGamma': 2,
                                  'NodeDelta': 2,
                                  'NodeEpsilon': 2}},
             'Fence D':{'type': 'SCSI Reservation',
                        'host': 'fenced.host.org',
                        'ip':   '123.123.78.35',
                        'port': 5487,
                        'nodes': {'NodeAlpha': 2,
                                  'NodeBeta': 1,
                                  'NodeGamma': 2}}}


class ClusterTwo(Cluster):
    """Data for 'ClusterTwo'."""
    def __init__(self):
        self.status = self.CLUSTER_OK
        self.cluster_votes = 2
        self.required_quorum = 1

        self.nodes = \
            {'NodeAlpha 2':   {'ip':          '144.92.235.11',
                             'serviceload': 10,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service W 2'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeBeta 2':    {'ip':          '144.92.235.12',
                             'serviceload': 20,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service X 2', 'Service Y 2', 'Service Z 2'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeDelta 2':   {'ip':          '144.92.235.13',
                             'serviceload': 30,
                             'status':      self.NODE_INACTIVE,
                             'msg': 'Something terrible',
                             'services':    ('Service X 2'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeGamma 2':   {'ip':          '144.92.235.14',
                             'serviceload': 40,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service Y 2'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeEpsilon 2': {'ip':          '144.92.235.15',
                             'serviceload': 50,
                             'status':      self.NODE_UNKNOWN,
                             'services':    ('Service Z 2'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}}}

        self.services = \
            {'Service W 2':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover1 2',
                            'node':      'NodeGamma 2',
                            'resources': {'Res A': ('Script', False)}},
            'Service Y 2':   {'running':   False,
                            'autostart': False,
                            #'failover':   None,
                            'node':      'NodeAlpha 2',
                            'resources': {'Res A': ('Script', False)}},
            'Service X 2':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover2',
                            'node':      'NodeBeta 2',
                            'resources': {'Resource1': ('Script',False),
                                          'Resource2': ('Apache',True),
                                          'Resource3': ('LVM',False),
                                          'Resource4': ('IP Address',True),
                                          'Resource5': ('GFS File System',False)}},
            'Service Z 2':   {'running':   False,
                            'autostart': True,
                            #'failover':   None,
                            'node':      'NodeDelta 2',
                            'resources': {'Res A': ('Script', False)}}}

        self.failovers = \
            {'Failover1 2':{'prioritized': False,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service Y 2',
                                          'Service X 2'),
                          'nodes':       {'NodeAlpha 2': 1,
                                          'NodeBeta 2': 2}},
             'Failover2 2':{'prioritized': True,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service X 2',
                                          'Service Y 2',
                                          'Service Z 2'),
                          'nodes':       {'NodeAlpha 2': 1,
                                          'NodeBeta 2': 2,
                                          'NodeEpsilon 2': 0}},
             'FDOM a 2':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service W 2',
                                          'Service Z 2'),
                          'nodes':       {'NodeBeta 2': 2,
                                          'NodeGamma 2': 0}},
             'FDOM b 2':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service Y 2'),
                          'nodes':       {'NodeDelta 2': 0,
                                          'NodeGamma 2': 0}},
             'FDOM c 2':   {'prioritized': True,
                          'restricted':  True,
                          'failback':    True,
                          'services':    ('Service Z 2',
                                          'Service X 2',
                                          'Service W 2'),
                          'nodes':       {'NodeAlpha 2': 1,
                                          'NodeEpsilon 2': 0}}}

        self.fences = \
            {'Fence A 2':{'type': 'iLO',
                        'host': 'hostname.host.org',
                        'ip':   '123.123.78.90',
                        'port': 6666,
                        'nodes': {'NodeDelta 2': 1}},
             'Fence B 2':{'type': 'APC Power Device',
                        'host': 'fenceb.host.org',
                        'ip':   '123.123.78.11',
                        'port': 6667,
                        'nodes': {'NodeAlpha 2': 1,
                                  'NodeDelta 2': 2}},
             'Fence C 2':{'type': 'Virtual Machine',
                        'host': 'fencec.host.org',
                        'ip':   '123.123.78.156',
                        'port': 11023,
                        'nodes': {'NodeAlpha 2': 1,
                                  'NodeBeta 2': 2,
                                  'NodeGamma 2': 2,
                                  'NodeDelta 2': 2,
                                  'NodeEpsilon 2': 2}},
             'Fence D 2':{'type': 'SCSI Reservation',
                        'host': 'fenced.host.org',
                        'ip':   '123.123.78.35',
                        'port': 5487,
                        'nodes': {'NodeAlpha 2': 2,
                                  'NodeBeta 2': 1,
                                  'NodeGamma 2': 2}}}


class ClusterThree(Cluster):
    """Data for 'ClusterThree'."""
    def __init__(self):

        self.status = self.CLUSTER_OK
        self.cluster_votes = 2
        self.required_quorum = 1

        self.nodes = \
            {'NodeAlpha 3':   {'ip':          '144.92.235.11',
                             'serviceload': 10,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service W 3'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeBeta 3':    {'ip':          '144.92.235.12',
                             'serviceload': 20,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service X 3', 'Service Y 3', 'Service Z 3'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeDelta 3':   {'ip':          '144.92.235.13',
                             'serviceload': 30,
                             'status':      self.NODE_INACTIVE,
                             'msg': 'Something terrible',
                             'services':    ('Service X 3'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeGamma 3':   {'ip':          '144.92.235.14',
                             'serviceload': 40,
                             'status':      self.NODE_ACTIVE,
                             'services':    ('Service Y 3'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}},
             'NodeEpsilon 3': {'ip':          '144.92.235.15',
                             'serviceload': 50,
                             'status':      self.NODE_UNKNOWN,
                             'services':    ('Service Z 3'),
                             'cman':        {'running': True, 'autostart': True},
                             'rgmanager':   {'running': True, 'autostart': True}}}

        self.services = \
            {'Service W 3':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover1 3',
                            'node':      'NodeGamma 3',
                            'resources': {'Res A': ('Script', False)}},
            'Service Y 3':   {'running':   False,
                            'autostart': False,
                            #'failover':   None,
                            'node':      'NodeAlpha 3',
                            'resources': {'Res A': ('Script', False)}},
            'Service X 3':   {'running':   True,
                            'autostart': True,
                            'failover':   'Failover2 3',
                            'node':      'NodeBeta 3',
                            'resources': {'Resource1': ('Script',False),
                                          'Resource2': ('Apache',True),
                                          'Resource3': ('LVM',False),
                                          'Resource4': ('IP Address',True),
                                          'Resource5': ('GFS File System',False)}},
            'Service Z 3':   {'running':   False,
                            'autostart': True,
                            #'failover':   None,
                            'node':      'NodeDelta 3',
                            'resources': {'Res A': ('Script', False)}}}

        self.failovers = \
            {'Failover1 3':{'prioritized': False,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service Y 3',
                                          'Service X 3'),
                          'nodes':       {'NodeAlpha 3': 1,
                                          'NodeBeta 3': 2}},
             'Failover2 3':{'prioritized': True,
                          'restricted':  True,
                          'failback':    False,
                          'services':    ('Service X 3',
                                          'Service Y 3',
                                          'Service Z 3'),
                          'nodes':       {'NodeAlpha 3': 1,
                                          'NodeBeta 3': 2,
                                          'NodeEpsilon 3': 0}},
             'FDOM a 3':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service W 3',
                                          'Service Z 3'),
                          'nodes':       {'NodeBeta 3': 2,
                                          'NodeGamma 3': 0}},
             'FDOM b 3':   {'prioritized': True,
                          'restricted':  False,
                          'failback':    False,
                          'services':    ('Service Y 3'),
                          'nodes':       {'NodeDelta 3': 0,
                                          'NodeGamma 3': 0}},
             'FDOM c 3':   {'prioritized': True,
                          'restricted':  True,
                          'failback':    True,
                          'services':    ('Service Z 3',
                                          'Service X 3',
                                          'Service W 3'),
                          'nodes':       {'NodeAlpha 3': 1,
                                          'NodeEpsilon 3': 0}}}

        self.fences = \
            {'Fence A 3':{'type': 'iLO',
                        'host': 'hostname.host.org',
                        'ip':   '123.123.78.90',
                        'port': 6666,
                        'nodes': {'NodeDelta 3': 1}},
             'Fence B 3':{'type': 'APC Power Device',
                        'host': 'fenceb.host.org',
                        'ip':   '123.123.78.11',
                        'port': 6667,
                        'nodes': {'NodeAlpha 3': 1,
                                  'NodeDelta 3': 2}},
             'Fence C 3':{'type': 'Virtual Machine',
                        'host': 'fencec.host.org',
                        'ip':   '123.123.78.156',
                        'port': 11023,
                        'nodes': {'NodeAlpha 3': 1,
                                  'NodeBeta 3': 2,
                                  'NodeGamma 3': 2,
                                  'NodeDelta 3': 2,
                                  'NodeEpsilon 3': 2}},
             'Fence D 3':{'type': 'SCSI Reservation',
                        'host': 'fenced.host.org',
                        'ip':   '123.123.78.35',
                        'port': 5487,
                        'nodes': {'NodeAlpha 3': 2,
                                  'NodeBeta 3': 1,
                                  'NodeGamma 3': 2}}}



# Certain storage.

class StorageA:
    """Data for 'storage_a'."""
    def __init__(self):
        self.total = 500
        self.drives = 2

class StorageB:
    """Data for 'storage_a'."""
    def __init__(self):
        self.total = 1500
        self.drives = 3

class StorageC:
    """Data for 'storage_a'."""
    def __init__(self):
        self.total = 400
        self.drives = 1

